@@ -26,26 +26,28 @@
  */
 
 #ifdef LIBBSD_OVERLAY
+#include <sys/cdefs.h>
+#if __has_include_next(<unistd.h>)
 #include_next <unistd.h>
+#endif
 #else
+#include <bsd/sys/cdefs.h>
+#if __has_include(<unistd.h>)
 #include <unistd.h>
 #endif
+#endif
 
 #ifndef LIBBSD_UNISTD_H
 #define LIBBSD_UNISTD_H
 
-#ifdef LIBBSD_OVERLAY
-#include <sys/cdefs.h>
-#else
-#include <bsd/sys/cdefs.h>
-#endif
 #include <sys/stat.h>
 
-#ifndef S_ISTXT
+#if !defined(S_ISTXT) && defined(S_ISVTX)
 #define S_ISTXT S_ISVTX
 #endif
 
 __BEGIN_DECLS
+#if !defined(__APPLE__)
 extern int optreset;
 
 #ifdef LIBBSD_OVERLAY
@@ -54,11 +56,16 @@ extern int optreset;
 #endif
 
 int bsd_getopt(int argc, char * const argv[], const char *shortopts);
+#endif
 
 mode_t getmode(const void *set, mode_t mode);
 void *setmode(const char *mode_str);
 
+#if !defined(__GLIBC__) || \
+    !__GLIBC_PREREQ(2, 34) || \
+    !defined(_DEFAULT_SOURCE)
 void closefrom(int lowfd);
+#endif
 
 /* Compatibility with sendmail implementations. */
 #define initsetproctitle(c, a, e) setproctitle_init((c), (a), (e))
