@@ -76,9 +76,9 @@
 			HD(b); \
 	} while (0)
 
-#define HR(x, l) (SHA512_Update(&ctx, (char *)(x), (l)))
-#define HD(x)	 (SHA512_Update(&ctx, (char *)&(x), sizeof (x)))
-#define HF(x)    (SHA512_Update(&ctx, (char *)&(x), sizeof (void*)))
+#define HR(x, l) (SHA512_Update(&ctx, (uint8_t *)(x), (l)))
+#define HD(x)	 (SHA512_Update(&ctx, (uint8_t *)&(x), sizeof (x)))
+#define HF(x)    (SHA512_Update(&ctx, (uint8_t *)&(x), sizeof (void*)))
 
 int	getentropy(void *buf, size_t len);
 
