@@ -35,6 +35,9 @@
 #include <errno.h>
 #include <string.h>
 #include <stdlib.h>
+#ifdef HAVE_PROCINFO_H
+#include <procinfo.h>
+#endif
 #ifdef _WIN32
 #include <Windows.h>
 #include <shlwapi.h>
@@ -62,6 +65,14 @@ getprogname(void)
 	/* getexecname(3) returns an absolute pathname, normalize it. */
 	if (__progname == NULL)
 		setprogname(getexecname());
+#elif defined(_AIX)
+	if (__progname == NULL) {
+		struct procentry64 procs;
+		pid_t pid = getpid ();
+
+		if (getprocs64(&procs, sizeof procs, NULL, 0, &pid, 1) > 0)
+			__progname = strdup(procs.pi_comm);
+	}
 #elif defined(_WIN32)
 	if (__progname == NULL) {
 		WCHAR *wpath = NULL;
@@ -126,6 +137,8 @@ done:
 		free(wpath);
 		free(mbname);
 	}
+#else
+#error "Function getprogname() needs to be ported."
 #endif
 
 	return __progname;
