@@ -289,17 +289,17 @@ setproctitle_impl(const char *fmt, ...)
 		*++nul = '\0';
 	}
 }
-libbsd_symver_default(setproctitle, setproctitle_impl, LIBBSD_0.5);
+libbsd_symver_default(setproctitle_impl, setproctitle, LIBBSD_0.5);
 
 /* The original function introduced in 0.2 was a stub, it only got implemented
  * in 0.5, make the implementation available in the old version as an alias
  * for code linking against that version, and change the default to use the
  * new version, so that new code depends on the implemented version. */
 #if defined(libbsd_strong_alias)
-libbsd_strong_alias(setproctitle_stub, setproctitle_impl);
+libbsd_strong_alias(setproctitle_impl, setproctitle_stub);
 #else
 void
 setproctitle_stub(const char *fmt, ...)
 	__attribute__((__alias__("setproctitle_impl")));
 #endif
-libbsd_symver_variant(setproctitle, setproctitle_stub, LIBBSD_0.2);
+libbsd_symver_variant(setproctitle_stub, setproctitle, LIBBSD_0.2);
