@@ -25,24 +25,51 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+static int
+test_memstream(void)
+{
+	int rc = 0;
+#if HAVE_OPEN_MEMSTREAM
+	FILE *fp;
+	char *buf = NULL;
+	size_t bufsz = 0;
+
+	fp = open_memstream(&buf, &bufsz);
+	if (fp == NULL)
+		return 1;
+
+	fputs("World", fp);
+	if (fpurge(fp) < 0)
+		rc = 1;
+	fflush(fp);
+	if (bufsz != 0)
+		rc = 1;
+
+	fclose(fp);
+	free(buf);
+#endif
+
+	return rc;
+}
 
 int
 main(int argc, char *argv[])
 {
-	static FILE fp_bad;
 	FILE *fp;
+	int rc;
 
 	if (fpurge(NULL) == 0)
 		return 1;
 
-	if (fpurge(&fp_bad) == 0)
-		return 1;
-
 	fp = fopen("/dev/zero", "r");
 	if (fpurge(fp) < 0)
 		return 1;
-
 	fclose(fp);
 
-	return 0;
+	rc = test_memstream();
+
+	return rc;
 }
